@@ -29,7 +29,8 @@ class GmailImapHook(BaseHook):
         All exceptions during logout and connection shutdown are caught because
         an error here usually means the connection was already closed.
         """
-        self.close()
+        # self.close()
+        pass
 
     def close(self):
         try:
@@ -71,9 +72,13 @@ class GmailImapHook(BaseHook):
         :rtype: bool
         """
         self.get_conn()
-        self.mail_client.select_folder('inbox')
 
-        self.mail_client.select('Inbox')
-        status, mails = self.mail_client.search(None, *mail_filter)
-        self.close()
+        self.mail_client.select('"[Gmail]/All Mail"')
+        if isinstance(mail_filter, list):
+            status, mails = self.mail_client.uid.search(None, *mail_filter)
+        else:
+            status, mails = self.mail_client.uid.search(None, mail_filter)
+        print(len(mails))
+        print(status)
+        # self.close()
         return len(mails) > 0
\ No newline at end of file
